config

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ClipseConfig = defaultConfig()

Global config object, accessed and used when any configuration is needed.

Functions

func AddClipboardItem

func AddClipboardItem(text, fp string) error

func ClearHistory

func ClearHistory(clearType string) error

func DeleteItems added in v0.1.0

func DeleteItems(timeStamps []string) error

func Init

func Init() error

func RemoveClipboardItem added in v1.1.1

func RemoveClipboardItem(index int) error

func SanitizeHistory added in v1.2.1

func SanitizeHistory() error

func TogglePinClipboardItem added in v0.0.7

func TogglePinClipboardItem(timeStamp string) (bool, error)

This pins and unpins an item in the clipboard

func WriteUpdate added in v0.1.0

func WriteUpdate(data ClipboardHistory) error

Types

type AutoPaste added in v1.1.1

type AutoPaste struct {
	Enabled bool   `json:"enabled"`
	Keybind string `json:"keybind"`
	Buffer  int    `json:"buffer"`
}

type ClipboardHistory

type ClipboardHistory struct {
	ClipboardHistory []ClipboardItem `json:"clipboardHistory"`
}

type ClipboardItem

type ClipboardItem struct {
	Value    string `json:"value"`
	Recorded string `json:"recorded"`
	FilePath string `json:"filePath"`
	Pinned   bool   `json:"pinned"`
}

func GetHistory

func GetHistory() []ClipboardItem

func TextItems added in v1.1.1

func TextItems() []ClipboardItem

type Config added in v0.0.7

type Config struct {
	AllowDuplicates   bool              `json:"allowDuplicates"`
	HistoryFilePath   string            `json:"historyFile"`
	MaxHistory        int               `json:"maxHistory"`
	DeleteAfter       int               `json:"deleteAfter"`
	LogFilePath       string            `json:"logFile"`
	PollInterval      int               `json:"pollInterval"`
	MaxEntryLength    int               `json:"maxEntryLength"`
	ThemeFilePath     string            `json:"themeFile"`
	TempDirPath       string            `json:"tempDir"`
	KeyBindings       map[string]string `json:"keyBindings"`
	ImageDisplay      ImageDisplay      `json:"imageDisplay"`
	ExcludedApps      []string          `json:"excludedApps"`
	AutoPaste         AutoPaste         `json:"autoPaste"`
	EnableMouse       bool              `json:"enableMouse"`
	EnableDescription bool              `json:"enableDescription"`
}

type CustomTheme

type CustomTheme struct {
	UseCustom          bool   `json:"useCustom"`
	TitleFore          string `json:"TitleFore"`
	TitleBack          string `json:"TitleBack"`
	TitleInfo          string `json:"TitleInfo"`
	NormalTitle        string `json:"NormalTitle"`
	DimmedTitle        string `json:"DimmedTitle"`
	SelectedTitle      string `json:"SelectedTitle"`
	NormalDesc         string `json:"NormalDesc"`
	DimmedDesc         string `json:"DimmedDesc"`
	SelectedDesc       string `json:"SelectedDesc"`
	StatusMsg          string `json:"StatusMsg"`
	PinIndicatorColor  string `json:"PinIndicatorColor"`
	SelectedBorder     string `json:"SelectedBorder"`
	SelectedDescBorder string `json:"SelectedDescBorder"`
	FilteredMatch      string `json:"FilteredMatch"`
	FilterPrompt       string `json:"FilterPrompt"`
	FilterInfo         string `json:"FilterInfo"`
	FilterText         string `json:"FilterText"`
	FilterCursor       string `json:"FilterCursor"`
	HelpKey            string `json:"HelpKey"`
	HelpDesc           string `json:"HelpDesc"`
	PageActiveDot      string `json:"PageActiveDot"`
	PageInactiveDot    string `json:"PageInactiveDot"`
	DividerDot         string `json:"DividerDot"`
	PreviewedText      string `json:"PreviewedText"`
	PreviewBorder      string `json:"PreviewBorder"`
}

func GetTheme

func GetTheme() CustomTheme

type ImageDisplay added in v1.1.0

type ImageDisplay struct {
	Type      string `json:"type"`
	ScaleX    int    `json:"scaleX"`
	ScaleY    int    `json:"scaleY"`
	HeightCut int    `json:"heightCut"`
}

Jump to